==> ejc-hrmanage-api-3.0.0-20231018.020143-28-sources.jar: com/ejianc/business/hr/vo/UnderReportVO.java <==
package com.ejianc.business.hr.vo;


import java.math.BigDecimal;

/**
 * 欠薪台账
 *
 * @author generator
 */
public class UnderReportVO{

    private String orgCode;
    private String orgName;
    private Integer year;
    private Integer month;
    private BigDecimal mny;
    private Integer num;
    private BigDecimal underMny;
    private Integer underNum;
    private BigDecimal totalMny;

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Integer getYear() {
        return year;
    }

    public void setYear(Integer year) {
        this.year = year;
    }

    public Integer getMonth() {
        return month;
    }

    public void setMonth(Integer month) {
        this.month = month;
    }

    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }

    public Integer getNum() {
        return num;
    }

    public void setNum(Integer num) {
        this.num = num;
    }

    public BigDecimal getUnderMny() {
        return underMny;
    }

    public void setUnderMny(BigDecimal underMny) {
        this.underMny = underMny;
    }

    public Integer getUnderNum() {
        return underNum;
    }

    public void setUnderNum(Integer underNum) {
        this.underNum = underNum;
    }

    public BigDecimal getTotalMny() {
        return totalMny;
    }

    public void setTotalMny(BigDecimal totalMny) {
        this.totalMny = totalMny;
    }
}

==> ejc-hrmanage-api-3.0.0-20251210.072145-201-sources.jar: com/ejianc/business/hr/vo/UnderReportVO.java <==
package com.ejianc.business.hr.vo;


import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 欠薪台账
 *
 * @author generator
 */
public class UnderReportVO{

    private String orgCode;
    private String orgName;
    private String departmentCode;
    private String departmentName;
    private Integer year;
    private Integer month;
    private BigDecimal mny;
    private Integer num;
    private BigDecimal underMny;
    private Integer underNum;
    private BigDecimal totalMny;
    @JsonFormat(pattern = "yyyy-MM", timezone = "GMT+8")
    private Date date;

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Integer getYear() {
        return year;
    }

    public void setYear(Integer year) {
        this.year = year;
    }

    public Integer getMonth() {
        return month;
    }

    public void setMonth(Integer month) {
        this.month = month;
    }

    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }

    public Integer getNum() {
        return num;
    }

    public void setNum(Integer num) {
        this.num = num;
    }

    public BigDecimal getUnderMny() {
        return underMny;
    }

    public void setUnderMny(BigDecimal underMny) {
        this.underMny = underMny;
    }

    public Integer getUnderNum() {
        return underNum;
    }

    public void setUnderNum(Integer underNum) {
        this.underNum = underNum;
    }

    public BigDecimal getTotalMny() {
        return totalMny;
    }

    public void setTotalMny(BigDecimal totalMny) {
        this.totalMny = totalMny;
    }

    public Date getDate() {
        return date;
    }

    public void setDate(Date date) {
        this.date = date;
    }

    public String getDepartmentCode() {
        return departmentCode;
    }

    public void setDepartmentCode(String departmentCode) {
        this.departmentCode = departmentCode;
    }

    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
}
